=========
Tutorials
=========

Here are some commonly available tutorial examples that you would adapt to run with this plugin. Before attempting the tutorials here, you need to have completed the steps in :doc:`../user_guide/installation` and started the verdi daemon as described in :doc:`../user_guide/aiida_sessions`.

.. toctree::
    :maxdepth: 3

    lysozyme
    genericMD
